Welcome to documentation for XLED - Smart LED Christmas lights!
===============================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme


Support
-------

.. toctree::
   :maxdepth: 2

   supported_operating_systems
   supported_python_versions
   supported_devices


Command Line Interface
----------------------

.. toctree::
   :maxdepth: 2

   cli_guide


Python API Documentation / Guide
--------------------------------

.. toctree::
   :maxdepth: 2

   xled


The Contributor Guide
---------------------

.. toctree::
   :maxdepth: 2

   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
